==> haskell-gtk2hs-buildtools-0.13.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.3.1
id: gtk2hs-buildtools-0.13.3.1-5DnT23n3tMp2R0qL0fsxQ9
key: gtk2hs-buildtools-0.13.3.1-5DnT23n3tMp2R0qL0fsxQ9
license: GPL-2
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
exposed: True
indefinite: False
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
abi: d60afb824cd20c3fd4b68f8343efe94f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gtk2hs-buildtools-0.13.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/gtk2hs-buildtools-0.13.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.3.1-5DnT23n3tMp2R0qL0fsxQ9
depends:
    base-4.10.1.0 process-1.6.1.0 array-0.5.2.0 pretty-1.1.3.3
    filepath-1.4.1.2 random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We Cabal-2.0.1.0
    directory-1.3.0.2 containers-0.5.10.2
    hashtables-1.2.2.1-D96UtOZkClK2Kw64wd465
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashtables-1.2.2.1-D96UtOZkClK2Kw64wd465=48247cff909dde2103c0a9bf3fcb8ec8
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.3.1
id: gtk2hs-buildtools-0.13.3.1-Cno1QjHtJvjAVdjCirg6la
key: gtk2hs-buildtools-0.13.3.1-Cno1QjHtJvjAVdjCirg6la
license: GPL-2
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
exposed: True
indefinite: False
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
abi: 512b62efa56591694ce4fa4798403bf6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gtk2hs-buildtools-0.13.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/gtk2hs-buildtools-0.13.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.3.1-Cno1QjHtJvjAVdjCirg6la
depends:
    base-4.10.1.0 process-1.6.1.0 array-0.5.2.0 pretty-1.1.3.3
    filepath-1.4.1.2 random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We Cabal-2.0.1.0
    directory-1.3.0.2 containers-0.5.10.2
    hashtables-1.2.2.1-6kbUH46g0mQ5yPL75AOOMY
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashtables-1.2.2.1-6kbUH46g0mQ5yPL75AOOMY=1ff3f21605be5303a5ae6c9464931a26
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
